@@ -22,17 +22,39 @@ Helper for TT Views.
 
 sub mk_compclass {
     my ( $self, $helper ) = @_;
-    my $file  = $helper->{file};
-    my $class = $helper->{class};
-    $helper->mk_file( $file, <<"EOF");
-package $class;
+    my $file = $helper->{file};
+    $helper->mk_file( 'compclass', $file );
+}
+
+=head1 SEE ALSO
+
+L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
+L<Catalyst::Response>, L<Catalyst::Helper>
+
+=head1 AUTHOR
+
+Sebastian Riedel, C<sri@oook.de>
+
+=head1 LICENSE
+
+This library is free software . You can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut
+
+1;
+
+__DATA__
+
+__compclass__
+package [% class %];
 
 use strict;
 use base 'Catalyst::View::TT';
 
 =head1 NAME
 
-$class - TT View Component
+[% class %] - TT View Component
 
 =head1 SYNOPSIS
 
@@ -54,23 +76,3 @@ the same terms as perl itself.
 =cut
 
 1;
-EOF
-}
-
-=head1 SEE ALSO
-
-L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
-L<Catalyst::Response>, L<Catalyst::Helper>
-
-=head1 AUTHOR
-
-Sebastian Riedel, C<sri@oook.de>
-
-=head1 LICENSE
-
-This library is free software . You can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut
-
-1;
